#
# spec file for package kf6-kirigami
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kirigami
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kirigami
Version:        6.11.0
Release:        1.1
Summary:        Set of QtQuick components
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-qt5compat-imports >= %{qt6_version}

%description
QtQuick plugins to build user interfaces based on the KDE UX guidelines.

%package imports
Summary:        Kirigami QML components
Requires:       kf6-kirigami-imports >= %{version}

%description imports
Kirigami QML and runtime components based on KF6 and Qt6

%package -n libKirigamiPlatform6
Summary:        Set of QtQuick components
Requires:       kf6-kirigami-imports >= %{version}
Recommends:     kf6-kirigami-imports = %{version}

%description -n libKirigamiPlatform6
QtQuick plugins to build user interfaces based on the KDE UX guidelines.
Based on Qt Quick Controls 2. This package contains the base shared libraries.

%package devel
Summary:        Development package for kirigami
Requires:       libKirigamiPlatform6 = %{version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Requires:       cmake(Qt6Concurrent) >= %{qt6_version}
Requires:       cmake(Qt6Qml) >= %{qt6_version}
Requires:       cmake(Qt6Quick) >= %{qt6_version}

%description devel
QtQuick plugins to build user interfaces based on the KDE UX guidelines.
Development files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build

%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang libkirigami6 --with-qt --without-mo

%ldconfig_scriptlets -n libKirigamiPlatform6

%files
%{_kf6_debugdir}/kirigami.categories

%files imports
%{_kf6_qmldir}/org/kde/kirigami/
# This is actually a plugin
%{_kf6_libdir}/libKirigamiPrivate.so.*

%files -n libKirigamiPlatform6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKirigami.so.*
%{_kf6_libdir}/libKirigamiDelegates.so.*
%{_kf6_libdir}/libKirigamiDialogs.so.*
%{_kf6_libdir}/libKirigamiLayouts.so.*
%{_kf6_libdir}/libKirigamiPlatform.so.*
%{_kf6_libdir}/libKirigamiPrimitives.so.*

%files devel
%doc %{_kf6_qchdir}/KF6KirigamiPlatform.*
%{_kf6_cmakedir}/KF6Kirigami/
%{_kf6_cmakedir}/KF6Kirigami2/
%{_kf6_cmakedir}/KF6KirigamiPlatform/
%dir %{_kf6_includedir}/Kirigami/
%{_kf6_includedir}/Kirigami/Platform/
%{_kf6_libdir}/libKirigami.so
%{_kf6_libdir}/libKirigamiDelegates.so
%{_kf6_libdir}/libKirigamiDialogs.so
%{_kf6_libdir}/libKirigamiLayouts.so
%{_kf6_libdir}/libKirigamiPlatform.so
%{_kf6_libdir}/libKirigamiPrimitives.so
%{_kf6_libdir}/libKirigamiPrivate.so
%{_kf6_sharedir}/kdevappwizard/templates/kirigami6.tar.bz2

%files lang -f libkirigami6.lang

%changelog
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Too many changes since 6.10.0, only listing bugfixes:
  * Revert "make sure the node is always at an integer position" (kde#484888)
  * SelectableLabel: disable shortcuts when invisible or no text selected (kde#498867)
  * Icon: fix absolute icon paths (kde#498288)
  * Dialog: include leading and trailing components in footer implicitWidth (kde#497795)
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Expose auto exclusive from AbstractButton to Kirigami.Action
  * Mnemonic: Emit sequence change also when it gets disabled
  * ListSectionHeader: set Accessible.role to Heading
  * controls/Card: set title as default Accessible.name
  * FormLayout: Set mnemonic only if buddy is visible and doesn't have one
  * FormLayout: Activate buddy with ShortcutFocusReason
  * qmltest: Avoid Qt module include
  * SearchDialog: Add emptyHelpfulAction
  * FormLayout: Make use of animateClick in shortcut activation
  * Don't overwrite menubar position
  * platformtheme: Set Accent color in highlight
  * Fix documentation referring to not existing Theme.smallSpacing
  * Ensure sidebar "y" position is only shifted when menubar/header is visible
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Chip: Add visible hover state
  * Fix accessibility of InlineMessage
  * ActionMenuItem: make a11y press work
  * PrivateActionToolButton: make a11y press work
  * SelectableLabel: Allow disabling the built-in context menu
  * Always use a ToolBar for pages on the stack
  * SelectableLabel: Make selection persistent (kde#496214)
  * PlaceholderMessage: Let use overwrite icon color
  * PlaceholderMessage: Forward icon.width/icon.height to internal Icon
  * NavigationTabBar: Fix warning related to assigning a Repeater instead of a AbstractButton
  * Use border for keyboard active focus in NavigationTabButton
  * SelectableLabel: Remove onLinkActivated
  * [SelectableLabel] restore font property
  * Add missing REQUIRED for ECM
  * Remove Useless empty contentItem
  * Fix mobile mode
  * Fix doc for PlatformTheme::ColorSet
  * ColumnView: Note that FixedColumns is the default value for columnResizeMode
  * Add optional Breeze style import also for static builds
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * TitleSubtitle: Don't explicit set renderType
  * Upper mound for overlaysheet width
  * SelectableLabel: fix a11y properties
  * Fix Kirigami Application (Qt6) template (kde#494478)
  * SelectableLabel: Use onPressedChanged
  * Reformat code with clang-format
  * Icon: Always respect the animated property (kde#466357)
  * Adjust tst_qicon for desktop theme
  * Fix loading desktop theme (kde#491294)
  * Fix presumable typos confusing background and foreground colors
  * Always print Theme file loading errors
  * SelectableLabel: override default padding values more completely (kde#495256)
  * Fix icon for positive state of InlineMessage
  * SelectableLabel: fix binding loop warning on cursorShape
  * ScrollablePage: Add properties to set if the scrollbars are interactive
  * SelectableLabel: use property alias instead of direct binding, expose more through aliases
  * Dialog: fix multiple binding loops (again)
  * Update version to 6.8.0
  * make the close button actually close
  * layout: Reverse the stacking order of items inserted into ToolBarLayout
  * Modify SelectableLabel to use TextEdit instead
  * Cleanup and fix static QML module installation
  * Disable PageRow gesture on android
  * Make OverlaySheet look exactly like Dialog (kde#489357)
  * Top align icon in multiline InlineMessage
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Add since info for new API
  * Re-enable cachegen on Android
  * Create CMake config file only once all build parameters are known
  * Fix unit tests when using a static build
  * PlatformTheme: fix crash when item is being destroyed
  * OverlaySheet: make default title vertically center aligned (kde#489357)
  * Fix clang-format version imcompatibilities
  * Dialog: Take header width into account, small fix for footerToolbar width
  * Workaround on incorrect palette update (kde#493654)
  * platform: Check if weak pointer is expired in PlatformThemeChangeTracker ctor (kde#493652)
  * Dialog: Use footer buttons width if its wider than content
  * Fix sidebar text color in systemsettings
  * Use disabled text colors also for inherit-ing Theme instances (kde#433256)
  * autotests/tst_theme: Add a test that verifies only one signal emission happens
  * autotests/tst_theme: Remove waiting for events
  * autotests/tst_theme: Explicitly mark root test objects as not inheriting
  * Add PlatformThemeChangeTracker to BasicTheme::sync()
  * platform: Replace PlatformTheme::queueChildUpdate with ChangeTracker::Data flag
  * platform: Don't use queued signals for batching change signals in PlatformTheme
  * Fix NavigationTabBar sizing on mobile
  * ContextualHelpButton: Clip to avoid text overflow
  * ContextualHelpButton: Fix flickering when the popup covers the button (kde#489688)
  * ColumnView currently allows having a QObject item inside its children list.
    This commit restricts this list from `QList<QObject *>` to
    `QList<QQuickItem *>` and removes redundant casts.
  * ToolBarLayout: Add support for actions that are separators
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Disable cachegen (kde#488326)
  * PlaceholderMessage: Remove the icon opacity if the message is actionable
  * ToolBarLayout: Add test for dynamic actions
  * Read willShowOnActive value as Variant and convert to Bool
  * PrivateActionToolButton: Replace onVisibleChanged with Connections
  * Fix registration name for WheelEvent
  * [icon] Only reload icon from theme if the theme has that icon (kde#491806)
  * PrivateActionToolButton: Hide menu if button is hidden (kde#486107)
  * Allow recoloring of Android icon theme
  * ci: add Alpine/musl job
  * [icon] Fix icon colors when using Plasma platformtheme and QIcon source (kde#491274)
  * ShadowedImage: Expose Image.status via a readonly alias
  * PromptDialog: fix buttons overflow
  * Relicense Chip to LGPL
  * Relicense LoadingPlaceholder to LGPL
- Drop patch, merged upstream:
  * 0001-Disable-cachegen.patch
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Add upstream change (kde#488326, boo#1228876):
  * 0001-Disable-cachegen.patch
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Relicense MenuDialog and PromptDialog to LGPL
  * GlobalDrawerActionItem: Fix tooltip
  * ContextualHelpButton: make text always accessible
  * Convert license headers to SPDX
  * Port dialogs to pragma ComponentBehavior: Bound
  * Dialog: Support variable base padding
  * Dialog: Add some null safety
  * Dialog: Fix ScrollView::contentItem management
  * Update version to 6.5.0
  * We can Use directly nullptr
  * fix: install KirigamiPrivate soversion
  * NavigationTabButton: Drop bold font workaround
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Add Kirigmai.Action unit tests
  * Fix static build
  * Allow initializing a Kirigami.Action from a QAction
  * NavigationTabButton: improve text legibility (kde#489573)
  * Dialog: Add horizontal padding to prevent content from leaking onto borders
  * ActionTextField: de-duplicate action icon code
  * dialogs/Dialog.qml: removed colorSet
  * ActionTextField: fix QML errors
  * Update build.gradle in application template to Qt 6
  * Remove unused KItemModels import
  * Fix: The issue of abnormal touch events
  * Relax property types to QtQuick.Templates counterparts
  * Units: decouple grid unit from font metrics
  * Fix typo
  * support USE_DBUS option to enable/disable dbus use
  * PlaceholderMessage: Announce the text and description to a11y (kde#482753)
  * fix: install KirigamiPrivate soversion
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Too many changes since 6.2.0, only listing bugfixes:
  * Revert "icon: Remove the node with lowest opacity when animation end" (kde#487577)
  * Card: emit toggled() when the user clicks on the header checkbox (kde#481461)
  * Always color icons (kde#485801)
* Mon May 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.1
  * New bugfix release
- Changes since 6.2.0:
  * Revert "Dialog: Always use an overlay as visual parent"
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Too many changes since 6.1.0, only listing bugfixes:
  * Fixed wrong navigation and dialog header button colors (kde#486163)
  * ContextualHelpButton: remove excess space from tooltip (kde#481817)
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * PromptDialog: Demote wrapper item from Control to Padding
  * ListSectionHeader: Clean up and expand docs, add import alias for Controls
  * PlatformTheme: Note where the disabled text color comes from
  * ImageColors: make sure QML attached object is fetched from main thread
  * Clarify that the default alignment for ActionToolbar is AlignLeft
  * Fix up qualified properties access and doc examples, use appropriate enum
    for TextEdit
  * ContextualHelpButton: Fix up code style and qualified property access
  * ContextualHelpButton: Use a specific and appropriate type for a property
  * ContextualHelpButton: Sort out imports and improve docs
  * padding: make sure to polish on completion (kde#477978)
  * PlaceholderMessage: remove bad example using it as a loading indicator
  * ContextualHelpButton: fix translated string usage
  * Adopt ContextualHelpButton
  * ApplicationItem & ApplicationWindow: Don't reserve space for overlaid vkbd
  * ColumnView: Disable invisible (out-of-viewport) pages
  * Make global drawer item keyboard navigable
  * Respect QT_NO_XDG_DESKTOP_PORTAL (kde#482730)
  * ColumnView: Add check args to clamp
  * ColumnView: Use OutExpo for page animation
  * Fix separator of OverlayDrawer in the header bar
  * ScrollablePage: Workaround Qt flickable inertia being really low See
  * Add Position paramenter for InlineMessage
  * Handle URL inputs for pushDialogLayer (kde#481623)
  * InlineMessage: Fix showing close button
  * Handle null drawer as well
  * Fix footer in layers (kde#480428)
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * Handle null drawer as well
  * Fix footer in layers (kde#480428)
  * update version for new release
  * Fix PassiveNotificationsManager height for wrapped text (kde#476021)
  * Update template
  * Units: make smallSpacing 4px and largeSpacing 8px
  * PageRow: Ensure JS-created pages have a parent set (kde#477977)
  * Mainpage.dox use correct URLs for types
  * OverlaySheet: Don't do custom positioning on mobile Otherwise the overlaysheet seems to go to the bottom of the screen, with a tiny height
  * pushDialogLayer: don't potentially override explicitly defined properties
  * Actually close drawers on Escape
  * Kirigami app template: bump min Qt/KF deps to match initial KF6 release
  * Set framecontrast to 0.2
  * workaround on the breakage in childAt introduced by the new headers
  * Refactor separator to use frameContrast, add lightFrameContrast
  * PagePoolAction: Do nothing if we're already showing the current page (kde#480837)
  * pushDialogLayer: don't implicitly convert properties to bool
  * Use Header color set on overlaydrawer
  * Use header color instead of window for columnview separator
  * Fix Overlay sheet size hints (kde#480673,kde#480508,kde#480147,kde#480514)
  * Set borders to follow same colors as Breeze widget style
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kirigami
